# OpenStreetMap Roads
The package takes an openstreetmap pbf file and converts it to a Trie with all the road network information
It provides an api to then do a fast map matching for any latitude, longitude that comes under the bounding box of the pbf file. 